============
Installation
============

Python Versions
===============

stevedore is tested under Python 3.6 and 3.7.

.. _install-basic:

Basic Installation
==================

stevedore should be installed into the same site-packages area where
the application and extensions are installed (either a virtualenv or
the global site-packages). You may need administrative privileges to
do that.  The easiest way to install it is using pip_::

  $ pip install stevedore

or::

  $ sudo pip install stevedore

.. _pip: http://pypi.org/project/pip

Download
========

stevedore releases are hosted on PyPI and can be downloaded from:
http://pypi.org/project/stevedore

Source Code
===========

The source is hosted on the OpenStack infrastructure: https://opendev.org/openstack/stevedore/

Entry point inspector
=====================

To list entrypoints and registered plugins this tool can be also very useful:
https://pypi.org/project/entry_point_inspector

Reporting Bugs
==============

Please report bugs through the launchpad project:
https://launchpad.net/python-stevedore
